Like ggplot2's facet_wrap/facet_grid but with a key improvement: each facet can have independent geom parameters and scales by default (instead of forced uniformity).
Arguments
- spec
A glyph_spec
- rows
Row faceting variable: a bare column name, a computed expression (e.g.
factor(cyl)), orNULL- cols
Column faceting variable: a bare column name, a computed expression, or
NULL- free_scales
"none", "x", "y", "both"
- wrap
If only one variable, wrap into a grid with this many columns